@@ -46,7 +46,7 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims =
     if (is.na(xmax)) 
         xmax <- max(m@frame[var2], na.rm = T)
     
-    steps <- eval(parse(text = paste0("length(unique(na.omit(m$model$",var2,")))")))
+    steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$",var2,")))")))
     if (steps > 100) steps <- 100 # avoid redundant calculation
     
     coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, 
@@ -92,7 +92,7 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims =
     if (is.na(xmax)) 
         xmax <- max(m@frame[var2], na.rm = T)
     
-    steps <- eval(parse(text = paste0("length(unique(na.omit(m$model$",var2,")))")))
+    steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$",var2,")))")))
     if (steps > 100) steps <- 100 # avoid redundant calculation
     
     coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, 
